package core

import (
	"time"

	log "github.com/sirupsen/logrus"
)

// UpdateContractAddressJob 定时更新合约内的地址
func (v *Validator) UpdateContractAddressJob() {
	ticker := time.NewTicker(time.Minute * 10)
	defer ticker.Stop()
	log.Info("start update address task")
	for {
		addrs, err := v.rpc.GetContainerAddresses()
		if err != nil {
			log.WithError(err).Error("failed to get container addresses")
		} else {
			v.containerAddresses = addrs
		}
		addrs, err = v.rpc.GetNMAddresses()
		if err != nil {
			log.WithError(err).Error("failed to get NM addresses")
		} else {
			v.nmAddresses = addrs
		}
		log.WithFields(log.Fields{
			"container_count": len(v.containerAddresses),
			"nm_count":        len(v.nmAddresses),
		}).Info("store contract update address")
		<-ticker.C
	}
}

// UpdateGlobalWorkloadJob 定时从quest更新全局workload
func (v *Validator) UpdateGlobalWorkloadJob() {
	ticker := time.NewTicker(time.Minute)
	defer ticker.Stop()
	log.Info("start update global workload task")
	for {
		wl := v.GetGlobalWorkload()
		if wl > 0 {
			v.pendingWorkload = wl
		}
		<-ticker.C
	}
}
